CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
90 lines
2.4 KiB
C++
90 lines
2.4 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
/**
|
|
* @addtogroup hipGetChannelDesc hipGetChannelDesc
|
|
* @{
|
|
* @ingroup TextureTest
|
|
* `hipGetChannelDesc(hipChannelFormatDesc* desc, hipArray_const_t array)` -
|
|
* Gets the channel descriptor in an array.
|
|
*/
|
|
|
|
#define R 8 // rows, height
|
|
#define C 8 // columns, width
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Creates a regular channel description.
|
|
* - Creates array using previously created description.
|
|
* - Checks that valid description is returned.
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/texture/hipGetChanDesc.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGetChannelDesc_CreateAndGet) {
|
|
CHECK_IMAGE_SUPPORT;
|
|
|
|
hipChannelFormatDesc chan_test, chan_desc;
|
|
hipArray_t hip_array;
|
|
|
|
chan_desc = hipCreateChannelDesc(32, 0, 0, 0, hipChannelFormatKindSigned);
|
|
HIP_CHECK(hipMallocArray(&hip_array, &chan_desc, C, R, 0));
|
|
HIP_CHECK(hipGetChannelDesc(&chan_test, hip_array));
|
|
|
|
if ((chan_test.x != 32) || (chan_test.y != 0) || (chan_test.z != 0) || (chan_test.f != 0)) {
|
|
INFO("Mismatch observed : " << chan_test.x << chan_test.y << chan_test.z << chan_test.f);
|
|
REQUIRE(false);
|
|
}
|
|
|
|
HIP_CHECK(hipFreeArray(hip_array));
|
|
}
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Validates handling of invalid arguments:
|
|
* -# When output pointer to the description is `nullptr`
|
|
* - Expected output: return `hipErrorInvalidValue`
|
|
* -# When array handle is `nullptr`
|
|
* - Expected output: return `hipErrorInvalidValue`
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/texture/hipGetChanDesc.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 5.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGetChannelDesc_Negative_Parameters) {
|
|
CHECK_IMAGE_SUPPORT;
|
|
|
|
hipChannelFormatDesc chan_test, chan_desc;
|
|
hipArray_t hip_array;
|
|
|
|
chan_desc = hipCreateChannelDesc(32, 0, 0, 0, hipChannelFormatKindSigned);
|
|
HIP_CHECK(hipMallocArray(&hip_array, &chan_desc, C, R, 0));
|
|
|
|
SECTION("desc is nullptr") {
|
|
HIP_CHECK_ERROR(hipGetChannelDesc(nullptr, hip_array), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("array is nullptr") {
|
|
HIP_CHECK_ERROR(hipGetChannelDesc(&chan_test, nullptr), hipErrorInvalidHandle);
|
|
}
|
|
|
|
HIP_CHECK(hipFreeArray(hip_array));
|
|
}
|
|
|
|
/**
|
|
* End doxygen group TextureTest.
|
|
* @}
|
|
*/
|